#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 18-1-27 上午9:09
# @Author  : Enoch.Xiang
# @Site    : shanghai
# @File    : collect
# @Contact : xiangwenzhuo@yeah.net
"""
import traceback
from utils import logger
import utils.decorator as decorator
import utils.result as result
import utils.exception as exception
import database.data_base as db
import database.base_init as init

LOG = logger.get_logger(__name__)
params_check = decorator.params_check


def takeTime(elem):
    return elem['time']


@params_check
def getcollecttrack(params):
    '''获取收藏的声音'''
    LOG.info('get collect service:')
    LOG.info('params is %s' % params)
    try:
        if 'uid' in params.keys():
            uid = params['uid']
            vin = params['vin']
            data = db.CollectTrack(vin, uid).get()
        else:
            vin = params['vin']
            uid = None
            data = db.CollectTrack(vin, uid).get()
        if data is False:
            return result.ErrorResult(exception.SQLConnectError())
        for i in data:
            i['id'] = i['track_id']
        return result.CollectResult(res=data)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def addcollecttrack(params):
    '''收藏声音'''
    LOG.info('add collect service:')
    LOG.info('params is %s' % params)
    try:
        timestamp = params['timestamp']
        if 'track_id' in params.keys():
            try:
                track_id = params['track_id']
            except:
                return result.ErrorResult(exception.NoTrackIdError())
            if 'uid' in params.keys():
                uid = params['uid']
                vin = params['vin']
                conn = init.Connect()
                data = db.CollectTrack(vin, uid, conn).add(timestamp, track_id)
                conn.close()
            else:
                vin = params['vin']
                uid = None
                conn = init.Connect()
                data = db.CollectTrack(vin, uid, conn).add(timestamp, track_id)
                conn.close()
            if data is False:
                return result.ErrorResult(exception.SQLConnectError())
            return result.CollectResult(res=data)
        else:
            return result.ErrorResult(exception.NoTrackIdError())

    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def cancelcollecttrack(params):
    '''取消收藏声音'''
    LOG.info('cancel collect service:')
    LOG.info('params is %s' % params)
    try:
        timestamp = params['timestamp']
        if 'track_id' in params.keys():
            track_id = params['track_id']
            if not len(track_id):
                return result.ErrorResult(exception.NoTrackIdError())
            if 'uid' in params.keys():
                uid = params['uid']
                vin = params['vin']
                conn = init.Connect()
                data = db.CollectTrack(vin, uid, conn).cancel(timestamp, track_id)
                conn.close()
            else:
                vin = params['vin']
                uid = None
                conn = init.Connect()
                data = db.CollectTrack(vin, uid, conn).cancel(timestamp, track_id)
                conn.close()
            if data is False:
                return result.ErrorResult(exception.SQLConnectError())
            return result.CollectResult(res=data)
        else:
            return result.ErrorResult(exception.NoTrackIdError())
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def getcollectplaylist(params):
    '''获取用户收藏听单'''
    LOG.info('get collect list service:')
    LOG.info('params is %s' % params)
    try:
        if 'uid' in params.keys():
            uid = params['uid']
            vin = params['vin']
            conn = init.Connect()
            data = db.CollectPlayList(vin, uid, conn).get()
            conn.close()
        else:
            vin = params['vin']
            uid = None
            conn = init.Connect()
            data = db.CollectPlayList(vin, uid, conn).get()
            conn.close()
        if data is False:
            return result.ErrorResult(exception.SQLConnectError())
        return result.CollectResult(res=data)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def addcollectplaylist(params):
    '''收藏听单'''
    LOG.info('add collect list service:')
    LOG.info('params is %s' % params)
    try:
        timestamp = params['timestamp']
        if 'playlistid' in params.keys():
            playlistid = params['playlistid']
            if 'uid' in params.keys():
                uid = params['uid']
                vin = params['vin']
                conn = init.Connect()
                data = db.CollectPlayList(vin, uid, conn).add(timestamp, playlistid)
                conn.close()
            else:
                vin = params['vin']
                uid = None
                conn = init.Connect()
                data = db.CollectPlayList(vin, uid, conn).add(timestamp, playlistid)
                conn.close()
            if data is False:
                return result.ErrorResult(exception.SQLConnectError())
            return result.CollectResult(res=data)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def cancelcollectplaylist(params):
    '''取消收藏听单'''
    LOG.info('cancel collect list service:')
    LOG.info('params is %s' % params)
    try:
        timestamp = params['timestamp']
        if 'playlistid' in params.keys():
            playlistid = params['playlistid']
            if 'uid' in params.keys():
                uid = params['uid']
                vin = params['vin']
                conn = init.Connect()
                data = db.CollectPlayList(vin, uid, conn).cancel(timestamp, playlistid)
                conn.close()
            else:
                vin = params['vin']
                uid = None
                conn = init.Connect()
                data = db.CollectPlayList(vin, uid, conn).cancel(timestamp, playlistid)
                conn.close()
            if data is False:
                return result.ErrorResult(exception.SQLConnectError())
            return result.CollectResult(res=data)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def getcollectalbum(params):
    """
    get collect albums
    :param params:
    :return:
    """
    LOG.info('get collect album service:')
    LOG.info('params is %s' % params)
    try:
        if 'uid' in params.keys():
            uid = params['uid']
            vin = params['vin']
            conn = init.Connect()
            data = db.CollectAlbum(vin, uid, conn).get()
            conn.close()
        else:
            vin = params['vin']
            uid = None
            conn = init.Connect()
            data = db.CollectAlbum(vin, uid, conn).get()
            conn.close()
        for i in data:
            i['id'] = i['album_id']
        data.sort(key=takeTime, reverse=True)
        if data is False:
            return result.ErrorResult(exception.SQLConnectError())
        return result.CollectResult(res=data)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def addcollectalbum(params):
    """
    add collect album
    :param params:
    :return:
    """
    LOG.info('add collect album service:')
    LOG.info('params is %s' % params)
    try:
        timestamp = params['timestamp']
        if 'album_id' in params.keys():
            album_id = params['album_id'].split()
            if not len(album_id):
                return result.ErrorResult(exception.NoArtistIdError())
            vin = params['vin']
            if 'uid' in params.keys():
                uid = params['uid']
            else:
                uid = None
            for i in album_id:
                conn = init.Connect()
                data = db.CollectAlbum(vin, uid, conn).add(timestamp, i)
                conn.close()
                if data is False:
                    return result.ErrorResult(exception.SQLConnectError())
                    break
                else:
                    data = data
            return result.CollectResult(res=data)
        else:
            return result.ErrorResult(exception.NoArtistIdError())
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def cancelcollectalbum(params):
    """
    cacel collect album
    :param params:
    :return:
    """
    LOG.info('cancel collect album server:')
    LOG.info('params is %s' % params)
    try:
        timestamp = params['timestamp']
        if 'album_id' in params.keys():
            album_id = params['album_id'].split()
            if not len(album_id):
                return result.ErrorResult(exception.NoAlbumIdError())
            vin = params['vin']
            if 'uid' in params.keys():
                uid = params['uid']
            else:
                uid = None
            for i in album_id:
                conn = init.Connect()
                data = db.CollectAlbum(vin, uid, conn).cancel(timestamp, i)
                conn.close()
                if data is False:
                    return result.ErrorResult(exception.SQLConnectError())
                    break
                else:
                    data = data
            return result.CollectResult(res=data)
        else:
            return result.ErrorResult(exception.NoAlbumIdError())
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def getcollectradio(params):
    """
    get collect radio
    :param params:
    :return:
    """
    LOG.info('get collect radio service:')
    LOG.info('params is %s' % params)
    try:
        if 'uid' in params.keys():
            uid = params['uid']
            vin = params['vin']
            conn = init.Connect()
            data = db.CollectRadio(vin, uid, conn).get()
            conn.close()
        else:
            vin = params['vin']
            uid = None
            conn = init.Connect()
            data = db.CollectRadio(vin, uid, conn).get()
            conn.close()
        if data is False:
            return result.ErrorResult(exception.SQLConnectError())
        return result.CollectResult(res=data)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def addcollectradio(params):
    """
    add collect radio
    :param params:
    :return:
    """
    LOG.info('add collect radio service:')
    LOG.info('params is %s' % params)
    try:
        timestamp = params['timestamp']
        if 'id' in params.keys():
            id = params['id'].split()
            if not len(id):
                return result.ErrorResult(exception.NoIdError())
            vin = params['vin']
            if 'uid' in params.keys():
                uid = params['uid']
            else:
                uid = None
            for i in id:
                conn = init.Connect()
                data = db.CollectRadio(vin, uid, conn).add(timestamp, i)
                conn.close()
                if data is False:
                    return result.ErrorResult(exception.SQLConnectError())
                    break
                else:
                    data = data
            return result.CollectResult(res=data)
        else:
            return result.ErrorResult(exception.NoIdError())
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def cancelcollectradio(params):
    """
    cacel collect radio
    :param params:
    :return:
    """
    LOG.info('cancel collect radio server:')
    LOG.info('params is %s' % params)
    try:
        timestamp = params['timestamp']
        if 'id' in params.keys():
            id = params['id'].split()
            if not len(id):
                return result.ErrorResult(exception.NoIdError())
            vin = params['vin']
            if 'uid' in params.keys():
                uid = params['uid']
            else:
                uid = None
            for i in id:
                conn = init.Connect()
                data = db.CollectRadio(vin, uid, conn).cancel(timestamp, i)
                conn.close()
                if data is False:
                    return result.ErrorResult(exception.SQLConnectError())
                    break
                else:
                    data = data
            return result.CollectResult(res=data)
        else:
            return result.ErrorResult(exception.NoIdError())
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def getcollectannouncer(params):
    """
    get collect announcer
    :param params:
    :return:
    """
    LOG.info('get collect announcer service:')
    LOG.info('params is %s' % params)
    try:
        if 'uid' in params.keys():
            uid = params['uid']
            vin = params['vin']
            conn = init.Connect()
            data = db.CollectAnnouncer(vin, uid, conn).get()
            conn.close()
        else:
            vin = params['vin']
            uid = None
            conn = init.Connect()
            data = db.CollectAnnouncer(vin, uid, conn).get()
            conn.close()
        if data is False:
            return result.ErrorResult(exception.SQLConnectError())
        return result.CollectResult(res=data)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def addcollectannouncer(params):
    """
    add collect radio
    :param params:
    :return:
    """
    LOG.info('add collect announcer service:')
    LOG.info('params is %s' % params)
    try:
        timestamp = params['timestamp']
        if 'id' in params.keys():
            id = params['id'].split()
            vin = params['vin']
            if 'uid' in params.keys():
                uid = params['uid']
            else:
                uid = None
            for i in id:
                conn = init.Connect()
                data = db.CollectAnnouncer(vin, uid, conn).add(timestamp, i)
                conn.close()
                if data is False:
                    return result.ErrorResult(exception.SQLConnectError())
                    break
                else:
                    data = data
            return result.CollectResult(res=data)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def cancelcollectannouncer(params):
    """
    cacel collect announcer
    :param params:
    :return:
    """
    LOG.info('cancel collect announcer server:')
    LOG.info('params is %s' % params)
    try:
        timestamp = params['timestamp']
        if 'id' in params.keys():
            id = params['id'].split()
            vin = params['vin']
            if 'uid' in params.keys():
                uid = params['uid']
            else:
                uid = None
            for i in id:
                conn = init.Connect()
                data = db.CollectAnnouncer(vin, uid, conn).cancel(timestamp, i)
                conn.close()
                if data is False:
                    return result.ErrorResult(exception.SQLConnectError())
                    break
                else:
                    data = data
            return result.CollectResult(res=data)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def getcollect(params):
    """
    get collect radio and album
    :param params:
    :return:
    """
    LOG.info('get collect radio service:')
    LOG.info('params is %s' % params)
    try:
        if 'uid' in params.keys():
            uid = params['uid']
            vin = params['vin']
            conn = init.Connect()
            data_1 = db.CollectRadio(vin, uid, conn).get()
            data_2 = db.CollectAlbum(vin, uid, conn).get()
            conn.close()
            data = []
            for i in data_1:
                i['kind'] = 'radio'
                data.append(i)
            for n in data_2:
                n['kind'] = 'album'
                data.append(n)
        else:
            vin = params['vin']
            uid = None
            conn = init.Connect()
            data_1 = db.CollectRadio(vin, uid, conn).get()
            data_2 = db.CollectAlbum(vin, uid, conn).get()
            conn.close()
            data = []
            for i in data_1:
                i['kind'] = 'radio'
                data.append(i)
            for n in data_2:
                n['kind'] = 'album'
                data.append(n)
        data.sort(key=takeTime, reverse=True)
        if data is False:
            return result.ErrorResult(exception.SQLConnectError())
        return result.CollectResult(res=data)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2017/10/20 10:19
# @Author  : guangze.yu/LiShuo
# @Site    : shanghai
# @File    : ximalayaAPI.py
# @Contact : guangze.yu@foxmail.com
"""

import API.common as common

Common = common.Common

class AnnouncersCategories(Common):
    '''获取喜马拉雅主播分类'''
    def __init__(self, param_dict):
        '''
        参数:公共参数.
        '''
        
        super(AnnouncersCategories, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/announcers/categories'

class AnnouncersList(Common):
    '''获取某个分类下的主播列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:vcategory_id,calc_dimension; 可选:page,count.
        vcategory_id:主播分类ID
        calc_dimension:返回的主播列表排序规则,取值和含义如下:1-最火 ,2-最新,3-粉丝最多
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'vcategory_id' in param_dict.keys(), 'There is no vcategory_id in the given params!'
        assert 'calc_dimension' in param_dict.keys(), 'There is no calc_dimension in the given params!'
        super(AnnouncersList, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/announcers/list'

class AnnouncersGetbatch(Common):
    '''根据一批主播ID批量获取主播信息'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:ids.
        ids:主播用户ID列表
        '''
        
        assert 'ids' in param_dict.keys(), 'There is no ids in the given params!'
        super(AnnouncersGetbatch, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/announcers/get_batch'

class AnnouncersAlbums(Common):
    '''获取某个主播的专辑列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:ids; 可选:page,count.
        aid:主播用户ID
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'aid' in param_dict.keys(), 'There is no aid in the given params!'
        super(AnnouncersAlbums, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/announcers/albums'

class AnnouncersTracks(Common):
    '''获取某个主播的声音列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:ids; 可选:page,count.
        aid:主播用户ID
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'aid' in param_dict.keys(), 'There is no aid in the given params!'
        super(AnnouncersTracks, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/announcers/tracks'


#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 18-1-26 下午10:26
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : logger
# @Contact : guangze.yu@foxmail.com
"""

import sys
import logging
import logging.handlers as handlers


def get_logger(log_name):
    """

    :param log_name:
    :return:
    """
    logger = logging.getLogger(log_name)
    formatter = logging.Formatter('%(asctime)s %(filename)s[line:%(lineno)d]'
                                  ' %(levelname)s %(message)s')
    file_handler = handlers.RotatingFileHandler("./log/%s.log" % log_name,
                                                maxBytes=10*1024*1024,
                                                backupCount=10)
    file_handler.setFormatter(formatter)
    console_handler = logging.StreamHandler(sys.stdout)
    console_handler.formatter = formatter
    logger.setLevel(logging.INFO)
    logger.addHandler(file_handler)
    logger.addHandler(console_handler)
    return logger



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 18-1-27 上午9:24
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : recommend
# @Contact : guangze.yu@foxmail.com
"""

import logger
import utils.decorator as decorator

LOG = logger.get_logger(__name__)
params_check = decorator.params_check



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 17-12-21 下午8:37
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : config
# @Contact : guangze.yu@foxmail.com
"""

########SQL DateBase config###############
sql = 'mysql'
tools = 'pymysql'
usr = 'root'
password = 'Root1q2w'
host = 'rm-uf6lp85qe22m65cu6oo.mysql.rds.aliyuncs.com:3306'
db_name = 'db_voice'
sqlconfig = '%s+%s://%s:%s@%s/%s?charset=utf8' %(sql,tools,usr,password,host,db_name)




#!/usr/bin/python3
# -*- coding: utf-8 -*-
"""
# @Time    : 2018/3/7 15:00
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : __init__.py
# @Project : roewe_voice 
# @Contact : guangze.yu@foxmail.com
"""


#!/usr/bin/python3
# -*- coding: utf-8 -*-
"""
# @Time    : 2018/3/13 12:35
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : response
# @Project : roewe_voice
# @Contact : guangze.yu@foxmail.com
"""


class Response(object):
    def __init__(self, app_result, request_path, method):
        """

        :param app_result:
        :param request_path:
        :param method:
        """
        self._result = app_result
        self._path = request_path
        self._method = method

    @property
    def info(self):
        res_info = {'data': self._result.response}
        return res_info

    def __repr__(self):
        return self.info



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2017/10/20 10:19
# @Author  : guangze.yu/LiShuo
# @Site    : shanghai
# @File    : ximalayaAPI.py
# @Contact : guangze.yu@foxmail.com
"""

import API.common as common

Common = common.Common

class LiveProvinces(Common):
    '''获取直播省市列表'''
    def __init__(self, param_dict):
        '''
        参数:公共参数.
        '''
        
        super(LiveProvinces, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/live/provinces'

class LiveRadios(Common):
    '''获取直播省市列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:radio_type;可选:province_code,page,count.
        radio_type:分类id,电台类型:1-国家台,2-省市台,3-网络台
        province_code:省份代码,radio_type为2时不能为空
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'radio_type' in param_dict.keys(), 'There is no radio_type in the given params!'
        super(LiveRadios, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/live/radios'

class LiveSchedules(Common):
    '''获取某个直播电台某一天的节目排期的列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:radio_id;可选:weekday.
        radio_id:直播电台id
        weekday:表示星期几,不填则取今天的星期.0-星期天,1-星期一,2-星期二,3-星期三,4-星期四,5-星期五,6-星期六
        '''
        
        assert 'radio_id' in param_dict.keys(), 'There is no radio_id in the given params!'
        super(LiveSchedules, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/live/schedules'

class LiveGetplayingprogram(Common):
    '''获取某个电台正在直播的节目'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:radio_id.
        radio_id:直播电台id
        '''
        
        assert 'radio_id' in param_dict.keys(), 'There is no radio_id in the given params!'
        super(LiveGetplayingprogram, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/live/get_playing_program'

class LiveCities(Common):
    '''获取某省份城市列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:province_code.
        province_code:省份code (国家行政规划的省代码)
        '''
        
        assert 'province_code' in param_dict.keys(), 'There is no province_code in the given params!'
        super(LiveCities, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/live/cities'

class LiveGetradiosbycity(Common):
    '''获取某省个城市下的电台列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:city_code; 可选:page,count.
        city_code:城市code(国家行政规划的城市代码)
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'city_code' in param_dict.keys(), 'There is no city_code in the given params!'
        super(LiveGetradiosbycity, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/live/get_radios_by_city'

class LiveGetradiosbyids(Common):
    '''根据电台ID,批量获取电台列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:ids.
        ids:电台ID列表,传参时用英文逗号分隔
        '''
        
        assert 'ids' in param_dict.keys(), 'There is no ids in the given params!'
        super(LiveGetradiosbyids, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/live/get_radios_by_ids'

class LiveRadiocategories(Common):
    '''获取直播电台的分类'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:id; 可选:kind,radio_category_name,order_num.
        id:直播分类ID
        kind:固定值"radio_category"
        radio_category_name:直播分类名称
        order_num:排序值,值越小排序越在前
        '''
        
        assert 'id' in param_dict.keys(), 'There is no id in the given params!'
        super(LiveRadiocategories, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/live/radio_categories'

class LiveGetradiobycategory(Common):
    '''根据电台分类获取直播电台数据'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:radio_category_id; 可选:page,count.
        radio_category_id:直播分类ID
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'radio_category_id' in param_dict.keys(), 'There is no radio_category_id in the given params!'
        super(LiveGetradiobycategory, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/live/get_radios_by_category'


# text = {'ids': 59}
# res = LiveGetradiosbyids(text).get()
# print(res)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2017/10/20 10:19
# @Author  : guangze.yu/LiShuo
# @Site    : shanghai
# @File    : ximalayaAPI.py
# @Contact : guangze.yu@foxmail.com
"""

import API.common as common

Common = common.Common

class PlayhistoryGetbyuid(Common):
    '''根据用户ID获取用户播放云历史记录'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:uid.
        uid:当前用户ID
        '''
        
        assert 'uid' in param_dict.keys(), 'There is no uid in the given params!'
        super(PlayhistoryGetbyuid, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/play_history/get_by_uid'

class PlayhistoryUpload(Common):
    '''用户上传播放云历史记录'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:uid,break_second;
        可选:content_type,album_id,track_id,radio_id,schedule_id,play_begin_at,play_end_at.
        uid:当前用户ID
        break_second:相对于音频开始位置的播放跳出位置,单位为秒.比如当前音频总时长60s,本次播放到音频第25s处就退出或者切到下一首,
                     那么break_second就是25
        content_type:-点播(不传时候的默认值),2-广播
        album_id:content_type=1时候必填,表示专辑ID
        track_id:content_type=1时候必填,为声音ID,表示具体播放专辑里哪条声音
        radio_id:content_type=2时候必填,表示广播电台ID
        schedule_id:content_type=2时候必填,表示收听的广播节目时间表ID
        play_begin_at:开始播放时刻,Unix毫秒数时间戳
        play_end_at:结束播放时刻,Unix毫秒数时间戳
        '''
        
        assert 'uid' in param_dict.keys(), 'There is no uid in the given params!'
        assert 'break_second' in param_dict.keys(), 'There is no break_second in the given params!'
        super(PlayhistoryUpload, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/play_history/upload'

class PlayhistoryBatchupload(Common):
    '''用户批量上传播放云历史记录'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:uid,play_history_records.
        uid:当前用户ID
        play_history_records:需要上传的播放数据列表,每条播放数据包含下列字段:
            content_type:1-点播,2-广播
            album_id:content_type=1时候必填,播放的专辑ID
            track_id:content_type=1时候必填,声音ID,表示具体播放专辑里哪条声音
            radio_id:content_type=2时候必填,表示广播电台ID
            schedule_id:content_type=2时候必填,表示收听的广播节目时间表ID
            break_second: 相对于音频开始位置的播放跳出位置,单位为秒.比如当前音频总时长60s,本次播放到音频第25s处就退出
                          或者切到下一首,那么break_second就是25
            play_begin_at:开始播放时刻,Unix毫秒数时间戳
            play_end_at:结束播放时刻,Unix毫秒数时间戳
        '''
        
        assert 'uid' in param_dict.keys(), 'There is no uid in the given params!'
        assert 'play_history_records' in param_dict.keys(), 'There is no play_history_records in the given params!'
        super(PlayhistoryBatchupload, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/play_history/batch_upload'

class PlayhistoryBatchdelete(Common):
    '''用户批量删除播放云历史记录'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:uid,play_history_records.
        uid:当前用户ID
        play_history_records:需要上传的播放数据列表,每条播放数据包含下列字段:
            content_type:1-点播,2-广播
            album_id:content_type=1时不为空,表示专辑ID
            track_id:content_type=1时不为空,表示声音ID
            radio_id:content_type=2时不为空,表示电台ID
            schedule_id:content_type=2时不为空,表示电台播放节目时间表ID
            delete_at:删除发生的时间点
        '''
        
        assert 'uid' in param_dict.keys(), 'There is no uid in the given params!'
        assert 'play_history_records' in param_dict.keys(), 'There is no play_history_records in the given params!'
        super(PlayhistoryBatchdelete, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/play_history/batch_delete'



# s = {'uid':'3284576'}
# t = PlayhistoryGetbyuid(s).get()
# print(t)
# #'error_desc': 'access_token is invalid or expired'

# s = {'uid':'2134325','break_second':'10'}
# t = PlayhistoryUpload(s).get()
# print(t)
# #'error_desc': 'access_token is invalid or expired'

# s = {'uid':'3284576'}
# t = PlayhistoryBatchupload(s).get()
# print(t)
##There is no play_history_records in the given params!

# s = {'uid':'3284576'}
# t = PlayhistoryBatchdelete(s).get()
# print(t)
# #There is no play_history_records in the given params!




#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 18-1-26 下午10:26
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : logger
# @Contact : guangze.yu@foxmail.com
"""
import logging
import sys

def get_logger(log_name):
    logger = logging.getLogger(log_name)
    formatter = logging.Formatter('%(asctime)s %(filename)s[line:%(lineno)d] %(levelname)s %(message)s')
    file_handler = logging.FileHandler("./log/%s.log"%log_name)
    file_handler.setFormatter(formatter)

    console_handler = logging.StreamHandler(sys.stdout)
    console_handler.formatter = formatter
    logger.setLevel(logging.INFO)
    logger.addHandler(file_handler)
    logger.addHandler(console_handler)
    return logger





#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2018/5/4 下午1:24
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : __init__
# @File    : app_music
# @Contact : guangze.yu@foxmail.com
"""


#!/usr/bin/python3
# -*- coding: utf-8 -*-
"""
# @Time    : 2018/3/9 11:13
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : result
# @Project : roewe_voice 
# @Contact : guangze.yu@foxmail.com
"""
import utils.exception as exception


class ResultBase(object):
    def __init__(self):
        self._status_code = None
        self._status_info = None
        self._response = None
        self._message = None

    @property
    def status_code(self):
        return self._status_code

    @property
    def status_info(self):
        return self._status_info

    @property
    def response(self):
        return self._response

    @property
    def message(self):
        if self._message is None:
            return self._message
        else:
            return self._message.message


class TestResult(ResultBase):
    def __init__(self, res, message=None):
        super(TestResult, self).__init__()
        self._status_code = exception.Success().code
        self._status_info = exception.Success().info
        self._response = res
        self._message = message


class ErrorResult(ResultBase):
    def __init__(self, error, message=None):
        super(ErrorResult, self).__init__()
        self._status_code = error.code
        self._status_info = error.info
        self._response = self._status_info
        self._message = message


class SearchResult(ResultBase):
    def __init__(self, res, message=None):
        super(SearchResult, self).__init__()
        self._status_code = exception.Success().code
        self._status_info = exception.Success().info
        self._response = res
        self._message = message


class CollectResult(ResultBase):
    def __init__(self, res, message=None):
        super(CollectResult, self).__init__()
        self._status_code = exception.Success().code
        self._status_info = exception.Success().info
        self._response = res
        self._message = message


class PlayResult(ResultBase):
    def __init__(self, res, message=None):
        super(PlayResult, self).__init__()
        self._status_code = exception.Success().code
        self._status_info = exception.Success().info
        self._response = res
        self._message = message


class PlayHistoryResult(ResultBase):
    def __init__(self, res, message=None):
        super(PlayHistoryResult, self).__init__()
        self._status_code = exception.Success().code
        self._status_info = exception.Success().info
        self._response = res
        self._message = message


class MoreInfoResult(ResultBase):
    def __init__(self, res, message=None):
        super(MoreInfoResult, self).__init__()
        self._status_code = exception.Success().code
        self._status_info = exception.Success().info
        self._response = res
        self._message = message


class PlayListResult(ResultBase):
    def __init__(self, res, message=None):
        super(PlayListResult, self).__init__()
        self._status_code = exception.Success().code
        self._status_info = exception.Success().info
        self._response = res
        self._message = message


class RecommandResult(ResultBase):
    def __init__(self, res, message=None):
        super(RecommandResult, self).__init__()
        self._status_code = exception.Success().code
        self._status_info = exception.Success().info
        self._response = res
        self._message = message


class AlbumResult(ResultBase):
    def __init__(self, res, message=None):
        super(AlbumResult, self).__init__()
        self._status_code = exception.Success().code
        self._status_info = exception.Success().info
        self._response = res
        self._message = message



#!/usr/bin/python3
# -*- coding: utf-8 -*-
"""
# @Time    : 2018/6/6 13:00
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : album
# @Project : roewe_voice 
# @Contact : guangze.yu@foxmail.com
"""

import API.common as common

Common = common.Common

class GetBatch(Common):
    def __init__(self, param_dict):
        '''Create a new categories_list object.
        :param  a dict, contain access_token
        参数:公共参数
        access_token:
        '''

        super(GetBatch, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/albums/get_batch'



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 18-1-27 上午9:14
# @Author  : Enoch.Xiang
# @Site    : shanghai
# @File    : play
# @Contact : xiangwenzhuo@yeah.net
"""

import database.data_base as db
import database.base_init as base_definition
import time
import API.demand as dem
import app.collect as col
import traceback
from utils import logger
import utils.result as result
import utils.exception as exception
import utils.decorator as decorator
import database.base_init as init


LOG = logger.get_logger(__name__)
params_check = decorator.params_check


def takeTime(elem):
    """
    function: 提取time字段
    :param elem:
    :return:
    """
    return elem['time']


@params_check
def play(params):
    '''播放声音'''
    LOG.info('play service:')
    LOG.info('params is %s' % params)
    try:
        vin = params['vin']
        timestamp = params['timestamp']
        if 'ids' in params.keys():
            ids = params['ids']
            if not len(ids):
                return result.ErrorResult(exception.NoIdsError())
        else:
            return result.ErrorResult(exception.NoIdsError())
        if 'uid' in params.keys():
            uid = params['uid']
        else:
            uid = None
        text = {'ids': ids}
        res = dem.TracksGetbatch(text).get()
        try:
            conn = base_definition.Connect()
            his = db.TracksHistoryList(vin, uid, conn)
            his.add(timestamp, ids)
            conn.close()
            collect_list = col.getcollecttrack(params).response
            collect_ids = []
            for i in collect_list:
                col_id = i['track_id']
                collect_ids.append(col_id)
            ids = int(ids)
            if ids in collect_ids:
                res['tracks'][0]['isLike'] = True
            else:
                res['tracks'][0]['isLike'] = False
        except:
            traceback.print_exc()
            LOG.exception('this is an data exception message')
        timestamp = float(params['timestamp'])
        a = time.time() - timestamp
        print('返回时间差%ss' % a)
        return result.PlayResult(res=res)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def index(params):
    '''返回标识位'''
    LOG.info('play service:')
    LOG.info('params is %s' % params)
    try:
        vin = params['vin']
        timestamp = params['timestamp']
        if 'ids' in params.keys():
            ids = params['ids']
        else:
            return result.ErrorResult(exception.NoTrackIdError())
        if 'uid' in params.keys():
            uid = params['uid']
        else:
            uid = None
        conn = init.Connect()
        record = db.UserTrackRecord(vin, uid, conn).get_position(ids)
        conn.close()
        if len(record) == 0:
            res = {}
        else:
            record.sort(key=takeTime, reverse=True)
            res = record[0]
        a = time.time() - timestamp
        print('返回时间差%ss' % a)
        return result.PlayResult(res=res)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def getlastplaytrack(params):
    '''获取上次播放所在页的声音'''
    LOG.info('getlasttrack service')
    LOG.info('param is %s' % params)
    try:
        if 'album_id' in params.keys():
            album_id = params['album_id']
        else:
            return result.ErrorResult(exception.NoAlbumIdError())
        if 'track_id' in params.keys():
            track_id = params['track_id']
        else:
            return result.ErrorResult(exception.NoTrackIdError)
        text = {'album_id': album_id, 'track_id': track_id}
        res = dem.TracksGetlastplaytracks(text).get()
        return result.PlayResult(res=res)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def record(params):
    """

    :param params:
    :return:
    """
    LOG.info('get last play record service')
    LOG.info('param is %s' % params)
    try:
        vin = params['vin']
        album_id = params['album_id']
        track_id = params['track_id']
        position = params['position']
        timestamp = params['timestamp']
        if 'uid' in params.keys():
            uid = params['uid']
        else:
            uid = None
        conn = base_definition.Connect()
        data = db.UserTrackRecord(vin, uid, conn).add(timestamp, album_id,
                                                         track_id, position)
        conn.close()
        if data is False:
            return result.ErrorResult(exception.SQLConnectError())
        return result.CollectResult(res=data)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())




#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2017/10/20 10:19
# @Author  : guangze.yu/LiShuo
# @Site    : shanghai
# @File    : ximalayaAPI.py
# @Contact : guangze.yu@foxmail.com
"""

import API.common as common

Common = common.Common

class CategoriesList(Common):
    '''获取喜马拉雅内容分类'''
    def __init__(self, param_dict):
        '''Create a new categories_list object.
        :param  a dict, contain access_token
        参数:公共参数
        access_token:
        '''
        
        super(CategoriesList, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/categories/list'

class V2TagsList(Common):
    '''获取声音或专辑的标签'''
    def __init__(self, param_dict):
        '''Create a new v2_tags object.
        :param  a dict, contain access_token, category_id, type
        参数:除公共参数外,必须包含:category_id, type
        category_id:分类ID,指定分类,为0时表示热门分类
        type:指定查询的是专辑标签还是声音标签,0-专辑标签
        '''
        
        assert 'category_id' in param_dict.keys(), 'There is no category_id in the given params!'
        assert 'type' in param_dict.keys(), 'There is no type in the given params!'
        super(V2TagsList, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/v2/tags/list'

class V2AlbumsList(Common):
    '''根据分类和标签获取某个分类某个标签下的热门专辑列表/最新专辑列表/最多播放专辑列表(V2版本)'''
    def __init__(self, param_dict):
        '''Create a new albums object.
        :param  a dict, contain access_token, category_id, optional param, contain calc_dimension, page and count
        参数:除公共参数外,必须包含:category_id,calc_dimension; 可选:tag_name,page,count.
        category_id:分类ID,指定分类,为0时表示热门分类
        calc_dimension:calc_dimension:计算维度,现支持最火(1),最新(2),经典或播放最多(3)
        tag_name:分类下对应的专辑标签
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'category_id' in param_dict.keys(), 'There is no category_id in the given params!'
        assert 'calc_dimension' in param_dict.keys(), 'There is no calc_dimension in the given params!'
        super(V2AlbumsList, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/v2/albums/list'

class AlbumsBrowse(Common):
    '''根据专辑ID获取专辑下的声音列表,即专辑浏览'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:album_id; 可选:sort,page,count.
        album_id:专辑ID
        sort:"asc"表示喜马拉雅正序,"desc"表示喜马拉雅倒序,"time_asc"表示时间升序,"time_desc"表示时间降序,默认为"asc"
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'album_id' in param_dict.keys(), 'There is no album_id in the given params!'
        super(AlbumsBrowse, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/albums/browse'

class AlbumsGetbatch(Common):
    '''批量获取专辑列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:ids.
        ids:专辑ID列表,传参时用英文逗号分割,最大ID数量为200个,超过200个的ID将忽略.
        '''
        
        assert 'ids' in param_dict.keys(), 'There is no ids in the given params!'
        super(AlbumsGetbatch, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/albums/get_batch'

class AlbumsGetupdatebatch(Common):
    '''根据专辑ID列表获取批量专辑更新提醒信息列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:ids.
        ids:专辑ID列表,传参时用英文逗号分隔.
        '''
        
        assert 'ids' in param_dict.keys(), 'There is no ids in the given params!'
        super(AlbumsGetupdatebatch, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/albums/get_update_batch'

class TracksHot(Common):
    '''根据分类和标签获取某个分类某个标签下的热门声音列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:category_id; 可选:tag_name,page,count.
        category_id:分类ID,指定分类,为0表示热门分类.
        tag_name:分类下对应声音标签,不填则为热门分类
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'category_id' in param_dict.keys(), 'There is no category_id in the given params!'
        super(TracksHot, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/tracks/hot'

class TracksGetbatch(Common):
    '''批量获取声音'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:ids.
        ids:声音ID列表,传参时用英文逗号分割,最大ID数量为200个,超过200个的ID将忽略.
        '''
        
        assert 'ids' in param_dict.keys(), 'There is no ids in the given params!'
        super(TracksGetbatch, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/tracks/get_batch'

class TracksGetlastplaytracks(Common):
    '''根据上一次所听声音的id,获取此声音所在那一页的声音'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:ablum_id,track_id; 可选:count,sort.
        ablum_id:专辑id
        track_id:声音id
        count:分页请求参数,表示每页多少条记录,默认20,最多不超过200
        sort:"asc"表示正序或"desc"表示倒序,默认为"asc"
        '''
        
        assert 'album_id' in param_dict.keys(), 'There is no album_id in the given params!'
        assert 'track_id' in param_dict.keys(), 'There is no track_id in the given params!'
        super(TracksGetlastplaytracks, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/tracks/get_last_play_tracks'

class MetadataList(Common):
    '''获取某个分类下的元数据列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:category_id.
        category_id:分类id,指定分类.
        '''
        
        assert 'category_id' in param_dict.keys(), 'There is no category_id in the given params!'
        super(MetadataList, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/metadata/list'

class MetadataAlbums(Common):
    '''获取某个分类的元数据属性键值组合下包含的热门专辑列表/最新专辑列表/最多播放专辑列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:category_id,calc_dimension;可选:metadata_attributes,page,count.
        category_id:分类id,指定分类,为0时表示热门分类.
        calc_dimension:计算维度,现支持最火(1),最新(2),经典或播放最多(3)
        metadata_attributes:元数据属性列表:在/metadata/list接口得到的结果中,取不同元数据属性的attr_key和atrr_value组成任意个数
                       的key-value键值,格式如:attr_key1:attr_value1;attr_key2:attr_value2;attr_key3:attr_value3
                       注意:此字段可为空,表示获取此分类下全部的最火、最新或者播放最多的专辑列表.
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'category_id' in param_dict.keys(), 'There is no category_id in the given params!'
        assert 'calc_dimension' in param_dict.keys(), 'There is no calc_dimension in the given params!'
        super(MetadataAlbums, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/metadata/albums'


# text = {'album_id': '86573', 'ids': '46430562', 'category_id': '13', 'calc_dimension': '1'}
# res = CategoriesList(text)
# res = MetadataList(text)
# res = MetadataAlbums(text)
# res2 = res.get()
# print(res2)



#!/usr/bin/python3
# -*- coding: utf-8 -*-
"""
# @Time    : 2018/3/9 11:07
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : expection
# @Project : roewe_voice 
# @Contact : guangze.yu@foxmail.com
"""
BASE_CODE = 30000


class Common(Exception):
    _status_code = 200
    _status_info = 'Success.'

    @property
    def code(self):
        return self._status_code

    @property
    def info(self):
        return self._status_info

    def __str__(self):
        return repr(self._status_info)


class Success(Common):
    _status_code = 0
    _status_info = 'Success.'


class InternalError(Common):
    _status_code = BASE_CODE + 500
    _status_info = 'Internal fault.'


class GetTokenFailed(Common):
    _status_code = BASE_CODE + 501
    _status_info = 'Get token failed from vendor.'


class NoTimeStampError(Common):
    _status_code = BASE_CODE + 1001
    _status_info = 'No timestamp in the request params!'


class NoVinError(Common):
    _status_code = BASE_CODE + 1002
    _status_info = 'No vin in the request params!'


class NoKeyWordError(Common):
    _status_code = BASE_CODE + 1003
    _status_info = 'No keyword in the request params!'


class PikaConnectionError(Common):
    _status_code = BASE_CODE + 1004
    _status_info = 'RabbitMQ connected error!'


class NoTrackIdError(Common):
    _status_code = BASE_CODE + 1005
    _status_info = 'No track id in the request params!'


class NoPlayListIdError(Common):
    _status_code = BASE_CODE + 1006
    _status_info = 'No playlist id in the request params!'


class NoAlbumIdError(Common):
    _status_code = BASE_CODE + 1007
    _status_info = 'No album id in the request params!'


class WebHandlerError(Common):
    _status_code = BASE_CODE + 1008
    _status_info = 'Error in the handler!'


class SQLConnectError(Common):
    _status_code = BASE_CODE + 1009
    _status_info = 'Database connect error!'


class CacheConnectError(Common):
    _status_code = BASE_CODE + 1010
    _status_info = 'Cache connect error!'


class NoItemIdError(Common):
    _status_code = BASE_CODE + 1011
    _status_info = 'No item id in the request params!'


class NoPlayListNameError(Common):
    _status_code = BASE_CODE + 1012
    _status_info = 'No playlistname in the request params!'


class NoSelfListError(Common):
    _status_code = BASE_CODE + 1013
    _status_info = 'No selflist in the request params!'


class NoArtistIdError(Common):
    _status_code = BASE_CODE + 1014
    _status_info = 'No artist id in the request params!'


class NoCategoryIdIdError(Common):
    _status_code = BASE_CODE + 1015
    _status_info = 'No categoryid id in the request params!'


class NoUserIdIdError(Common):
    _status_code = BASE_CODE + 1016
    _status_info = 'No user id in the request params!'


class NoTopError(Common):
    _status_code = BASE_CODE + 1017
    _status_info = 'No top in the request params!'


class NoIdsError(Common):
    _status_code = BASE_CODE + 1018
    _status_info = 'No ids the request params!'


class NoIdError(Common):
    _status_code = BASE_CODE + 1019
    _status_info = 'No id the request params!'



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2017/10/20 10:19
# @Author  : guangze.yu/LiShuo
# @Site    : shanghai
# @File    : ximalayaAPI.py
# @Contact : guangze.yu@foxmail.com
"""

import API.common as common

Common = common.Common

class ColdbootGenres(Common):
    '''获取冷启动一级分类'''
    def __init__(self, param_dict):
        '''
        参数:公共参数.
        '''
        
        super(ColdbootGenres, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/coldboot/genres'

class ColdbootSubgenres(Common):
    '''获取冷启动二级分类'''
    def __init__(self, param_dict):
        '''
        参数:公共参数.
        '''
        
        super(ColdbootSubgenres, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/coldboot/sub_genres'

class ColdbootTags(Common):
    '''根据冷启动一级分类和冷启动二级分类获取相应类别下的冷启动标签列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:coldboot_genre,coldboot_sub_genre.
        coldboot_genre:冷启动分类
        coldboot_sub_genre:冷启动二级分类
        '''
        
        assert 'coldboot_genre' in param_dict.keys(), 'There is no coldboot_genre in the given params!'
        assert 'coldboot_sub_genre' in param_dict.keys(), 'There is no coldboot_sub_genre in the given params!'
        super(ColdbootTags, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/coldboot/tags'

class ColdbootSubmittags(Common):
    '''提交用户感兴趣的冷启动标签'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:coldboot_genre,coldboot_sub_genre,device_type,device_id,coldboot_tags.
        coldboot_genre:冷启动分类
        coldboot_sub_genre:冷启动二级分类
        device_type:1-ios,2-android,3-pc
        device_id:设备唯一标识,如果公共参数里已经有device_id 参数则不需要再传
        coldboot_tags:用户勾选的感兴趣的冷启动标签列表
        '''
        
        assert 'coldboot_genre' in param_dict.keys(), 'There is no coldboot_genre in the given params!'
        assert 'coldboot_sub_genre' in param_dict.keys(), 'There is no coldboot_sub_genre in the given params!'
        assert 'device_type' in param_dict.keys(), 'There is no device_type in the given params!'
        assert 'device_id' in param_dict.keys(), 'There is no device_id in the given params!'
        assert 'coldboot_tags' in param_dict.keys(), 'There is no coldboot_tags in the given params!'
        super(ColdbootSubmittags, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/coldboot/submit_tags'

class ColdbootDetail(Common):
    '''获取用户提交的冷启动标签详情'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:device_type,device_id.
        device_type:1-ios,2-android,3-pc
        device_id:设备唯一标识,如果公共参数里已经有device_id 参数则不需要再传
        '''
        
        assert 'device_type' in param_dict.keys(), 'There is no device_type in the given params!'
        assert 'device_id' in param_dict.keys(), 'There is no device_id in the given params!'
        super(ColdbootDetail, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/coldboot/detail'


#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2017/10/20 10:19
# @Author  : guangze.yu/LiShuo
# @Site    : shanghai
# @File    : ximalayaAPI.py
# @Contact : guangze.yu@foxmail.com
"""

import API.common as common

Common = common.Common

class BannersRankbanners(Common):
    '''获取榜单的焦点图列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,可选:channel,app_version,image_scale.
        channel:app的渠道号(对应渠道焦点图配置),默认值为"and-f5"
        app_version:app版本号,默认值为"4.3.2.2"
        image_scale:控制焦点图图片大小参数,scale=2为iphone适配类型,scale=3为iphone6适配机型,对于Android一般设为2,默认为2.
        '''
        
        super(BannersRankbanners, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/banners/rank_banners'

class BannersDiscoverybanners(Common):
    '''获取发现页推荐的焦点图列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,可选:channel,app_version,image_scale.
        channel:app的渠道号(对应渠道焦点图配置),默认值为"and-f5"
        app_version:app版本号,默认值为"4.3.2.2"
        image_scale:控制焦点图图片大小参数,scale=2为iphone适配类型,scale=3为iphone6适配机型,对于Android一般设为2,默认为2.
        '''
        
        super(BannersDiscoverybanners, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/banners/discovery_banners'

class BannersCategorybanners(Common):
    '''获取分类推荐的焦点图列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:category_id,content_type; 可选:channel,app_version,image_scale.
        category_id:分类ID
        content_type:内容类型:暂时仅专辑(album)
        channel:app的渠道号(对应渠道焦点图配置),默认值为"and-f5"
        app_version:app版本号,默认值为"4.3.2.2"
        image_scale:控制焦点图图片大小参数,scale=2为iphone适配类型,scale=3为iphone6适配机型,对于Android一般设为2,默认为2.
        '''
        
        assert 'category_id' in param_dict.keys(), 'There is no category_id in the given params!'
        assert 'content_type' in param_dict.keys(), 'There is no content_type in the given params!'
        super(BannersCategorybanners, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/banners/category_banners'


from setuptools import setup, find_packages

# with open('demo_project_test_time/requirements.txt') as f:
#     required = f.read().splitlines()

setup(
    name="app_voice",
    version="0.001",
    packages=find_packages(),
    py_modules=["API", "server", "app", "config", "database", "docs", "mq", "rec", "server", "utils"],
    include_package_data=True,
    platforms="any",
    install_requires=["numpy",
                      "pandas",
                      "tornado",
                      "redis",
                      "sqlalchemy",
                      "kazoo",
                      "pika",
                      "ruamel.yaml",
                      "requests",
                      "pymysql"
                      ],
    # data_files=[('bitmaps', ['bm/b1.gif', 'bm/b2.gif']),
    # ('config', ['cfg/data.cfg']), ('/etc/init.d', ['init-script'])]
    data_files=[('config', ['app_voice/config/app_voice.conf'])]
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 18-1-26 下午2:33
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : testhandler
# @Contact : guangze.yu@foxmail.com
"""

import traceback
import json
import tornado.web as web
import tornado.gen as gen
import tornado.concurrent as concurrent
import server.response as res
import utils.result as result
from utils import logger
from utils.exception import WebHandlerError, PikaConnectionError

LOG = logger.get_logger(__name__)


class CommonHandler(web.RequestHandler):
    """
    common handler for the request.
    """
    mod = __import__('app.test', globals(), locals(), ['object'], 0)
    executor = concurrent.futures.ThreadPoolExecutor(100)

    @web.asynchronous
    @gen.coroutine
    def post(self, service):
        """

        :param service:
        :return:
        """
        path = self.request.path
        LOG.info('request path:%s', path)
        LOG.info('request ip:%s', self.request.remote_ip)
        vin = self.request.headers.get_list('vin')
        uid = self.request.headers.get_list('User_id')
        timestamp = self.request.headers.get_list('Timestamp')
        try:
            self.pika_connect()
        except PikaConnectionError:
            traceback.print_exc()
            LOG.info('Rabbitmq connect failuer.')
        try:
            body_params = self.request.body
            if body_params.decode('utf-8'):
                params = json.loads(body_params.decode('utf-8'))
            else:
                params = {}
            if vin:
                params['vin'] = vin[0]
            if uid:
                params['uid'] = uid[0]
            if timestamp:
                params['timestamp'] = timestamp[0]
            LOG.info('request params:%s', params)
            app_result = yield self.async_fun(service, params)
        except WebHandlerError:
            traceback.print_exc()
            app_result = result.ErrorResult(WebHandlerError())
        return_info = res.Response(app_result, path, 'POST').info
        message = app_result.message
        self.set_header("Content-Type", "application/json")
        self.set_header("Status_code", app_result.status_code)
        self.set_header("Status_info", app_result.status_info)
        self.write(return_info)
        self.finish()
        if message is not None:
            self.application.mq.channel.queue_declare(callback=None,
                                                      queue='voice',
                                                      durable=True)
            self.application.mq.channel.basic_publish(exchange='',
                                                      routing_key='voice',
                                                      body=json.dumps(message))

    def pika_connect(self):
        """

        :return:
        """
        self.application.mq.connect()

    @concurrent.run_on_executor
    def async_fun(self, service, params):
        """

        :param service:
        :param params:
        :return:
        """
        func = getattr(self.mod, service)
        return func(params)


class RoeweVoiceSearchHandler(CommonHandler):
    mod = __import__('app.search', globals(), locals(), ['object'], 0)


class RoeweVoiceCollectHandler(CommonHandler):
    mod = __import__('app.collect', globals(), locals(), ['object'], 0)


class RoeweVoicePlayHistoryHandler(CommonHandler):
    mod = __import__('app.playhistory', globals(), locals(), ['object'], 0)


class RoeweVoicePlayListHandler(CommonHandler):
    mod = __import__('app.playlist', globals(), locals(), ['object'], 0)


class RoeweVoicePlayHandler(CommonHandler):
    mod = __import__('app.play', globals(), locals(), ['object'], 0)


class RoeweVoiceMoreInfoHandler(CommonHandler):
    mod = __import__('app.more', globals(), locals(), ['object'], 0)


class RoeweVoiceRecommendHandler(CommonHandler):
    mod = __import__('app.recommend', globals(), locals(), ['object'], 0)


class RoeweVoiceAlbumHandler(CommonHandler):
    mod = __import__('app.album', globals(), locals(), ['object'], 0)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 18-1-27 上午9:11
# @Author  : Enoch.Xiang
# @Site    : shanghai
# @File    : playhistory
# @Contact : xiangwenzhuo@yeah.net
"""

import utils.result as result
import utils.exception as exception
import utils.decorator as decorator
import database.base_init as init
import traceback
import database.data_base as db
import logger
import datetime

LOG = logger.get_logger(__name__)
params_check = decorator.params_check


@params_check
def gethistory(params):
    '''历史记录'''
    LOG.info('playhistory service:')
    LOG.info('params is %s' % params)
    try:
        if 'uid' in params.keys():
            uid = params['uid']
            vin = params['vin']
            conn = init.Connect()
            historylist = db.TracksHistoryList(vin, uid, conn).get()
            conn.close()
        else:
            vin = params['vin']
            conn = init.Connect()
            historylist = db.TracksHistoryList(vin, conn).get()
            conn.close()
        historylist = historylist[0:100]
        for i in historylist:
            i['id'] = i['track_id']
        return result.PlayHistoryResult(res=historylist)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def clearhistory(params):
    """清空历史记录"""
    LOG.info('clear playhistory service:')
    LOG.info('params is %s', params)
    # end_time = datetime.datetime.now()
    # start_time = end_time - datetime.timedelta(180)
    try:
        if 'uid' in params.keys():
            uid = params['uid']
            vin = params['vin']
            conn = init.Connect()
            historylist = db.TracksHistoryList(vin, uid, conn).clear()
            conn.close()
        else:
            uid = None
            vin = params['vin']
            conn = init.Connect()
            historylist = db.TracksHistoryList(vin, uid, conn).clear()
            conn.close()
        return result.PlayHistoryResult(res=historylist)
    except exception.InternalError:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


#!/usr/bin/python3
# -*- coding: utf-8 -*-
"""
# @Time    : 2018/3/12 14:11
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : mess
# @Project : roewe_voice 
# @Contact : guangze.yu@foxmail.com
"""
import json


class MessBase(object):
    def __init__(self, mess_cls, method, info, level='C'):
        """

        :param mess_cls:
        :param method:
        :param info:
        :param level:
        """
        self._level = level
        self._class = mess_cls
        self._info = info
        self._method = method

    @property
    def message(self):
        return {'level': self._level,
                'class': self._class,
                'method': self._method,
                'info': self._info}

    def __repr__(self):
        return json.dumps(self.message)


class SearchWordsHistory(MessBase):
    def __init__(self, method, info):
        """

        :param method:
        :param info:
        """
        super(SearchWordsHistory, self).__init__(mess_cls='SearchWordHistory',
                                                 method=method,
                                                 info=info,
                                                 level='C')


class TracksHistoryList(MessBase):
    def __init__(self, method, info):
        """

        :param method:
        :param info:
        """
        super(TracksHistoryList, self).__init__(mess_cls='TracksHistoryList',
                                                method=method,
                                                info=info,
                                                level='C')


class CollectTrack(MessBase):
    def __init__(self, method, info):
        """

        :param method:
        :param info:
        """
        super(CollectTrack, self).__init__(mess_cls='CollectTrack',
                                           method=method,
                                           info=info,
                                           level='A')


class CollectPlayList(MessBase):
    def __init__(self, method, info):
        """

        :param method:
        :param info:
        """
        super(CollectPlayList, self).__init__(mess_cls='CollectTrack',
                                              method=method,
                                              info=info,
                                              level='A')


class UserPlaylist(MessBase):
    def __init__(self, method, info):
        """

        :param method:
        :param info:
        """
        super(UserPlaylist, self).__init__(mess_cls='UserPlaylist',
                                           method=method,
                                           info=info,
                                           level='A')


class SongHistoryList(MessBase):
    def __init__(self, method, info):
        """

        :param method:
        :param info:
        """
        super(SongHistoryList, self).__init__(mess_cls='SongHistoryList',
                                              method=method,
                                              info=info,
                                              level='C')



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 18-1-27 上午11:39
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : common
# @Contact : guangze.yu@foxmail.com
"""
import requests
import base64
import time
import random
import string
import hashlib
import json
import hmac
import redis

app_key = '7809fdad2a6c299d8d13b0a232e15350'
app_secret = 'a1bfc4d4a0e1bb5c51ca097f6bd28c51'
pack_id = 'com.ximalaya.ting.android.car.shangqichengyongche'
bundle_id = 'com.ximalaya.ting.android.car.shangqichengyongche'
device_id = 'E4B3185B0932'

pool = redis.ConnectionPool(host='127.0.0.1', password='Root1q2w', port=6379)
cache = redis.Redis(connection_pool=pool)
def signature(param):
    msg = ''
    param_sorted = {i: str(param[i]) for i in sorted(param.keys())}
    for i in param_sorted:
        msg += '&'+i+'='+param_sorted[i]
    msg_byte = bytes(msg[1:],'utf-8')
    msg_base64 = bytes(base64.encodebytes(msg_byte).decode('utf-8').replace('\n',''),'utf-8')
    key = bytes(app_secret, 'utf-8')
    msg_hmac_sha1 = hmac.new(key, msg_base64, hashlib.sha1).digest()
    sig = hashlib.md5(msg_hmac_sha1).hexdigest()
    return sig

class Oauth2(object):
    def __init__(self):
        self.app_key = app_key
        self.device_id = device_id
        self.grant_type = 'client_credentials'
        self.nonce = ''.join(random.sample(string.ascii_letters + string.digits, 8))
        self.timestamp = str(int(time.time()*1000))
        self.url = 'http://api.ximalaya.com/oauth2/secure_access_token'
        self.access_token = self.login()

    def login(self):
        headers = {'ContentType':'application/x-www-form-urlencoded'}
        param = {'client_id':self.app_key, 'device_id':self.device_id,'grant_type': self.grant_type, 'nonce':self.nonce,
                 'timestamp':self.timestamp}
        sig = signature(param)
        param['sig'] = sig
        access = requests.post(self.url,headers=headers, data=param)
        text = json.loads(access.content.decode('utf-8'))
        access_token = text['access_token']
        expires_time = text['expires_in']
        cache.set('ximalaya_token',access_token,expires_time)
        return access_token

def get_token():
    token = cache.get('ximalaya_token')
    if token is None:
        token = Oauth2().login()
    else:
        token = token.decode('utf-8')
    return token

class Common(object):
    def __init__(self):
        self._access_token = get_token()
        self._client_os_type = '3'
        self._app_key = app_key
        self._device_id = device_id
        self._pack_id = pack_id
        self._param_public = {'access_token':self._access_token, 'app_key':self._app_key, 'client_os_type':
            self._client_os_type, 'device_id':self._device_id,'pack_id':self._pack_id}
        self._param_private = {}
        self._url = 'http://api.ximalaya.com'

    def get(self):
        param = self._param_public.copy()
        param.update(self._param_private)
        sig = signature(param)
        param['sig'] = sig
        res = requests.get(self._url, param)
        return json.loads(res.content.decode('utf-8'))

    def update(self, param_dict):
        self._param_private = param_dict